@@ -33,6 +33,7 @@
 
 #include <QAbstractItemView>
 #include <QAbstractScrollArea>
+
 #include <QCommonStyle>
 #include <QDockWidget>
 #include <QHash>
@@ -41,6 +42,10 @@
 #include <QStyleOption>
 #include <QWidget>
 
+#if QT_VERSION >= 0x050000
+#include <QCommandLinkButton>
+#endif
+
 namespace BreezePrivate
 {
     class TabBarData;
@@ -137,6 +142,10 @@ namespace Breeze
         bool eventFilterDockWidget( QDockWidget*, QEvent* );
         bool eventFilterMdiSubWindow( QMdiSubWindow*, QEvent* );
 
+        #if QT_VERSION >= 0x050000
+        bool eventFilterCommandLinkButton( QCommandLinkButton*, QEvent* );
+        #endif
+
         //* install event filter to object, in a unique way
         void addEventFilter( QObject* object )
         {
@@ -318,7 +327,10 @@ namespace Breeze
         //@{
 
         //* spinbox arrows
-        void renderSpinBoxArrow( QPainter*, const QStyleOptionSpinBox*, const QWidget*, const SubControl& ) const;
+        void renderSpinBoxArrow( const SubControl&, const QStyleOptionSpinBox*, QPainter*, const QWidget*) const;
+
+        //* menu title
+        void renderMenuTitle( const QStyleOptionToolButton*, QPainter*, const QWidget* ) const;
 
         //* return dial angle based on option and value
         qreal dialAngle( const QStyleOptionSlider*, int ) const;
@@ -439,6 +451,9 @@ namespace Breeze
         //* return true if one of the widget's parent inherits requested type
         template<typename T> bool hasParent( const QWidget* ) const;
 
+        //* return true if passed widget is a menu title (KMenu::addTitle)
+        bool isMenuTitle( const QWidget* ) const;
+
         private:
 
         //*@name scrollbar button types (for addLine and subLine )
